AnchorSelection
===============

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: AnchorSelection
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AnchorSelection.__call__
      ~AnchorSelection.extra_repr
      ~AnchorSelection.filter_unique

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: extra_repr
   .. automethod:: filter_unique
